==> eslint-config-motor-talk-5.0.0.tgz: package/rules/es6.js <==
module.exports = {
    'env': {
        'es6': true
    },
    'parserOptions': {
        'ecmaVersion': 6,
        'sourceType': 'module',
        'ecmaFeatures': {
            'jsx': true,
            'generators': false,
            'objectLiteralDuplicateProperties': false,
            'experimentalObjectRestSpread': true
        }
    },
    'rules': {
        // enforces no braces where they can be omitted
        // http://eslint.org/docs/rules/arrow-body-style
        'arrow-body-style': [2, 'as-needed'],
        // require parens in arrow function arguments
        'arrow-parens': 0,
        // require space before/after arrow function's arrow
        // https://github.com/eslint/eslint/blob/master/docs/rules/arrow-spacing.md
        'arrow-spacing': [2, { 'before': true, 'after': true }],
        // disallow trailing commas in multiline object literals
        'comma-dangle': [2, 'never'],
        // verify super() callings in constructors
        'constructor-super': 0,
        // enforce the spacing around the * in generator functions
        'generator-star-spacing': 0,
        // disallow modifying variables of class declarations
        'no-class-assign': 0,
        // disallow arrow functions where they could be confused with comparisons
        // http://eslint.org/docs/rules/no-confusing-arrow
        'no-confusing-arrow': 0,
        // disallow modifying variables that are declared using const
        'no-const-assign': 2,
        // disallow symbol constructor
        // http://eslint.org/docs/rules/no-new-symbol
        'no-new-symbol': 2,
        // disallow specific globals
        'no-restricted-globals': 0,
        // disallow specific imports
        // http://eslint.org/docs/rules/no-restricted-imports
        'no-restricted-imports': 0,
        // disallow to use this/super before super() calling in constructors.
        'no-this-before-super': 0,
        // require let or const instead of var
        'no-var': 2,
        // disallow unnecessary constructor
        // http://eslint.org/docs/rules/no-useless-constructor
        'no-useless-constructor': 2,
        // require method and property shorthand syntax for object literals
        // https://github.com/eslint/eslint/blob/master/docs/rules/object-shorthand.md
        'object-shorthand': [2, 'always'],
        // suggest using arrow functions as callbacks
        'prefer-arrow-callback': 2,
        // suggest using of const declaration for variables that are never modified after declared
        'prefer-const': 2,
        // suggest using the spread operator instead of .apply()
        'prefer-spread': 0,
        // suggest using Reflect methods where applicable
        'prefer-reflect': 0,
        // use rest parameters instead of arguments
        // http://eslint.org/docs/rules/prefer-rest-params
        'prefer-rest-params': 2,
        // suggest using template literals instead of string concatenation
        // http://eslint.org/docs/rules/prefer-template
        'prefer-template': 1,
        // disallow generator functions that do not have yield
        'require-yield': 0,
        // import sorting
        // http://eslint.org/docs/rules/sort-imports
        'sort-imports': 0,
        // enforce usage of spacing in template strings
        // http://eslint.org/docs/rules/template-curly-spacing
        'template-curly-spacing': 2,
        // enforce spacing around the * in yield* expressions
        // http://eslint.org/docs/rules/yield-star-spacing
        'yield-star-spacing': [2, 'after']
    }
};

==> eslint-config-motor-talk-5.0.1.tgz: package/rules/es6.js <==
module.exports = {
    'env': {
        'es6': true
    },
    'parserOptions': {
        'ecmaVersion': 2018,
        'sourceType': 'module',
        'ecmaFeatures': {
            'jsx': true,
            'generators': false,
            'objectLiteralDuplicateProperties': false
        }
    },
    'rules': {
        // enforces no braces where they can be omitted
        // http://eslint.org/docs/rules/arrow-body-style
        'arrow-body-style': [2, 'as-needed'],
        // require parens in arrow function arguments
        'arrow-parens': 0,
        // require space before/after arrow function's arrow
        // https://github.com/eslint/eslint/blob/master/docs/rules/arrow-spacing.md
        'arrow-spacing': [2, { 'before': true, 'after': true }],
        // disallow trailing commas in multiline object literals
        'comma-dangle': [2, 'never'],
        // verify super() callings in constructors
        'constructor-super': 0,
        // enforce the spacing around the * in generator functions
        'generator-star-spacing': 0,
        // disallow modifying variables of class declarations
        'no-class-assign': 0,
        // disallow arrow functions where they could be confused with comparisons
        // http://eslint.org/docs/rules/no-confusing-arrow
        'no-confusing-arrow': 0,
        // disallow modifying variables that are declared using const
        'no-const-assign': 2,
        // disallow symbol constructor
        // http://eslint.org/docs/rules/no-new-symbol
        'no-new-symbol': 2,
        // disallow specific globals
        'no-restricted-globals': 0,
        // disallow specific imports
        // http://eslint.org/docs/rules/no-restricted-imports
        'no-restricted-imports': 0,
        // disallow to use this/super before super() calling in constructors.
        'no-this-before-super': 0,
        // require let or const instead of var
        'no-var': 2,
        // disallow unnecessary constructor
        // http://eslint.org/docs/rules/no-useless-constructor
        'no-useless-constructor': 2,
        // require method and property shorthand syntax for object literals
        // https://github.com/eslint/eslint/blob/master/docs/rules/object-shorthand.md
        'object-shorthand': [2, 'always'],
        // suggest using arrow functions as callbacks
        'prefer-arrow-callback': 2,
        // suggest using of const declaration for variables that are never modified after declared
        'prefer-const': 2,
        // suggest using the spread operator instead of .apply()
        'prefer-spread': 0,
        // suggest using Reflect methods where applicable
        'prefer-reflect': 0,
        // use rest parameters instead of arguments
        // http://eslint.org/docs/rules/prefer-rest-params
        'prefer-rest-params': 2,
        // suggest using template literals instead of string concatenation
        // http://eslint.org/docs/rules/prefer-template
        'prefer-template': 1,
        // disallow generator functions that do not have yield
        'require-yield': 0,
        // import sorting
        // http://eslint.org/docs/rules/sort-imports
        'sort-imports': 0,
        // enforce usage of spacing in template strings
        // http://eslint.org/docs/rules/template-curly-spacing
        'template-curly-spacing': 2,
        // enforce spacing around the * in yield* expressions
        // http://eslint.org/docs/rules/yield-star-spacing
        'yield-star-spacing': [2, 'after']
    }
};
